@@ -2,7 +2,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "incidencewrapper.h"
-#include "calendarmanager.h"
 #include "merkuro_calendar_debug.h"
 #include "utils.h"
 #include <KLocalizedString>
@@ -481,7 +480,7 @@ KCalendarCore::Recurrence *IncidenceWrapper::recurrence() const
 QVariantMap IncidenceWrapper::recurrenceData()
 {
     QBitArray weekDaysBits = m_incidence->recurrence()->days();
-    QVector<bool> weekDaysBools(7);
+    QList<bool> weekDaysBools(7);
 
     for (int i = 0; i < weekDaysBits.size(); i++) {
         weekDaysBools[i] = weekDaysBits[i];
@@ -864,3 +863,5 @@ void IncidenceWrapper::setCollection(const Akonadi::Collection &collection)
 #ifndef UNITY_CMAKE_SUPPORT
 Q_DECLARE_METATYPE(KCalendarCore::Incidence::Ptr)
 #endif
+
+#include "moc_incidencewrapper.cpp"
